Return key should not be ignored in multiline edit even if
ES_WANTRETURN flag isn't set.

diff --git a/controls/edit.c b/controls/edit.c
index a2318c8..1e53fb7 100644
--- a/controls/edit.c
+++ b/controls/edit.c
@@ -2896,8 +2896,8 @@
         BOOL control = GetKeyState(VK_CONTROL) & 0x8000;
 	switch (c) {
 	case '\r':
-	    /* If the edit doesn't want the return, do nothing */
-	    if(!(es->style & ES_WANTRETURN))
+	    /* If the edit doesn't want the return and it's not a multiline edit, do nothing */
+	    if(!(es->style & ES_MULTILINE) && !(es->style & ES_WANTRETURN))
 		break;
 	case '\n':
 		if (es->style & ES_MULTILINE) {